@@ -48,8 +48,7 @@ from xphyle.types import (
 
 
 class ThreadsVar:
-    """Maintain ``threads`` variable.
-    """
+    """Maintain ``threads`` variable."""
 
     def __init__(self, default_value: int = 1) -> None:
         self.threads = default_value
@@ -172,18 +171,15 @@ class SystemReader(SystemIO):
         return "rb"
 
     def readable(self) -> bool:
-        """Implementing file interface; returns True.
-        """
+        """Implementing file interface; returns True."""
         return True
 
     def flush(self) -> None:
-        """Implementing file interface; no-op.
-        """
+        """Implementing file interface; no-op."""
         pass
 
     def close(self) -> None:
-        """Close the reader; terminates the underlying process.
-        """
+        """Close the reader; terminates the underlying process."""
         self._closed = True
         retcode = self.process.poll()
         if retcode is None:
@@ -262,23 +258,19 @@ class SystemWriter(SystemIO):
         return "wb"
 
     def writable(self) -> bool:
-        """Implementing file interface; returns True.
-        """
+        """Implementing file interface; returns True."""
         return True
 
     def write(self, arg) -> int:
-        """Write to stdin of the underlying process.
-        """
+        """Write to stdin of the underlying process."""
         return self.process.stdin.write(arg)
 
     def flush(self) -> None:
-        """Flush stdin of the underlying process.
-        """
+        """Flush stdin of the underlying process."""
         self.process.stdin.flush()
 
     def close(self) -> None:
-        """Close the writer; terminates the underlying process.
-        """
+        """Close the writer; terminates the underlying process."""
         self._closed = True
         self.process.stdin.close()
         retcode = self.process.wait()
@@ -299,27 +291,23 @@ class CompressionFormat(FileFormat):
     @property
     @abstractmethod
     def name(self) -> str:
-        """The canonical format name.
-        """
+        """The canonical format name."""
         pass
 
     @property
     @abstractmethod
     def exts(self) -> Tuple[str, ...]:
-        """The commonly used file extensions.
-        """
+        """The commonly used file extensions."""
         pass
 
     @property
     def allowed_exts(self) -> Tuple[str, ...]:
-        """Extensions that are allowed to be used. Defaults to `self.exts`.
-        """
+        """Extensions that are allowed to be used. Defaults to `self.exts`."""
         return self.exts
 
     @property
     def system_commands(self) -> Tuple[str, ...]:
-        """The names of the system-level commands, in order of preference.
-        """
+        """The names of the system-level commands, in order of preference."""
         return (self.name,)
 
     @property
@@ -331,54 +319,48 @@ class CompressionFormat(FileFormat):
 
     @property
     def compresslevel_range(self) -> Optional[Tuple[int, int]]:  # pragma: no-cover
-        """The range of valid compression levels: (lowest, highest).
-        """
+        """The range of valid compression levels: (lowest, highest)."""
         return None
 
     @property
     @abstractmethod
     def compress_path(self) -> PurePath:
-        """The path of the compression program.
-        """
+        """The path of the compression program."""
         pass
 
     @property
     @abstractmethod
     def decompress_path(self) -> PurePath:
-        """The path of the decompression program.
-        """
+        """The path of the decompression program."""
         pass
 
     @property
     def compress_name(self) -> str:
-        """The name of the compression program.
-        """
+        """The name of the compression program."""
         return self.compress_path.name
 
     @property
     def decompress_name(self) -> str:
-        """The name of the decompression program.
-        """
+        """The name of the decompression program."""
         return self.decompress_path.name
 
     @property
     @abstractmethod
-    def magic_bytes(self) -> Tuple[Tuple[int, ...], ...]:
+    def magic_bytes(self) -> Optional[Tuple[Tuple[int, ...], ...]]:
         """The initial bytes that indicate the file type.
+        Returns None if the format does not have any set inital bytes.
         """
         pass
 
     @property
     @abstractmethod
     def mime_types(self) -> Tuple[str, ...]:
-        """The MIME types.
-        """
+        """The MIME types."""
         pass
 
     @property
     def aliases(self) -> Tuple:
-        """All of the aliases by which this format is known.
-        """
+        """All of the aliases by which this format is known."""
         aliases = set(self.exts)
         # if isinstance(fmt.system_commands, dict):
         #     aliases = aliases | set(fmt.system_commands.values())
@@ -389,8 +371,7 @@ class CompressionFormat(FileFormat):
 
     @property
     def default_ext(self) -> str:
-        """The default file extension for this format.
-        """
+        """The default file extension for this format."""
         return self.exts[0]
 
     def _get_compresslevel(self, level: int = None) -> int:
@@ -819,7 +800,9 @@ class CompressionFormat(FileFormat):
             A tuple (<compressed size in bytes>, <uncompressed size in bytes>,
             <compression ratio>).
         """
-        raise UnsupportedOperation()
+        raise UnsupportedOperation(
+            f"parse_file_listing not supported for format {self.name}"
+        )
 
     def uncompressed_size(self, path: PurePath) -> Optional[int]:
         """Get the uncompressed size of a compressed file.
@@ -841,8 +824,7 @@ class CompressionFormat(FileFormat):
 
 
 class Formats:
-    """Manages a set of compression formats.
-    """
+    """Manages a set of compression formats."""
 
     def __init__(self):
         self.compression_formats = {}
@@ -872,15 +854,16 @@ class Formats:
             # TODO: warn about overriding existing format?
             self.compression_format_aliases[alias] = fmt.name
 
-        for magic in fmt.magic_bytes:
-            self.max_magic_bytes = max(self.max_magic_bytes, len(magic))
-            self.magic_bytes[magic[0]].append((fmt.name, magic[1:]))
+        if fmt.magic_bytes is not None:
+            for magic in fmt.magic_bytes:
+                self.max_magic_bytes = max(self.max_magic_bytes, len(magic))
+                self.magic_bytes[magic[0]].append((fmt.name, magic[1:]))
+
         for mime in fmt.mime_types:
             self.mime_types[mime] = fmt.name
 
     def list_compression_formats(self) -> Tuple:
-        """Returns a list of all registered compression formats.
-        """
+        """Returns a list of all registered compression formats."""
         return tuple(self.compression_formats.keys())
 
     def list_extensions(self, with_sep: bool = False) -> Iterable[str]:
@@ -922,8 +905,7 @@ class Formats:
         raise ValueError("Unsupported compression format: {}".format(name))
 
     def get_compression_format_name(self, alias: str):
-        """Returns the cannonical name for the given alias.
-        """
+        """Returns the cannonical name for the given alias."""
         if alias in self.compression_formats:
             return alias
         return self.compression_format_aliases.get(alias, None)
@@ -952,7 +934,7 @@ class Formats:
 
         Note that ``path`` must be openable and readable. If it is a named pipe
         or other pseudo-file type, the magic bytes will be destructively
-        consumed and thus will open correctly.
+        consumed and thus will not open correctly.
 
         Args:
             path: Path to the file
@@ -1042,15 +1024,13 @@ class SingleExeCompressionFormat(
 
     @property
     def executable_path(self) -> PurePath:
-        """The path of the system executable.
-        """
+        """The path of the system executable."""
         self._resolve_executable()
         return self._executable_path
 
     @property
     def executable_name(self) -> str:
-        """The name of the system executable.
-        """
+        """The name of the system executable."""
         self._resolve_executable()
         return self._executable_name
 
@@ -1222,8 +1202,7 @@ class DualExeCompressionFormat(
 
 @compression_format
 class Gzip(SingleExeCompressionFormat):
-    """Implementation of CompressionFormat for gzip files.
-    """
+    """Implementation of CompressionFormat for gzip files."""
 
     @property
     def name(self) -> str:
@@ -1242,7 +1221,7 @@ class Gzip(SingleExeCompressionFormat):
         return 1 if self.executable_name == "igzip" else 4
 
     @property
-    def magic_bytes(self) -> Tuple[Tuple[int, ...], ...]:
+    def magic_bytes(self) -> Optional[Tuple[Tuple[int, ...], ...]]:
         return ((0x1F, 0x8B),)
 
     @property
@@ -1300,7 +1279,7 @@ class Gzip(SingleExeCompressionFormat):
             returncode = 1
         super().handle_command_return(returncode, cmd, stderr)
 
-    def get_list_command(self, path: PurePath) -> List[str]:
+    def get_list_command(self, path: PurePath) -> Optional[List[str]]:
         if self.executable_name == "igzip":
             # igzip doesn't have a -l option
             exe_path = EXECUTABLE_CACHE.resolve_exe(["gzip", "pigz"])[0]
@@ -1388,7 +1367,7 @@ class BGzip(DualExeCompressionFormat):
         return "pigz", "gzip"
 
     @property
-    def magic_bytes(self) -> Tuple[Tuple[int, ...], ...]:
+    def magic_bytes(self) -> Optional[Tuple[Tuple[int, ...], ...]]:
         return ((0x1F, 0x8B, 0x08, 0x04),)
 
     @property
@@ -1482,12 +1461,13 @@ class Zstd(SingleExeCompressionFormat):
         return 3
 
     @property
-    def magic_bytes(self) -> Tuple[Tuple[int, ...], ...]:
+    def magic_bytes(self) -> Optional[Tuple[Tuple[int, ...], ...]]:
         return (
-            (0xFD, 0x2F, 0xB5, 0x1E),  # v0.1
-            (0xFD, 0x2F, 0xB5, 0x22),  # v0.2
-            (0xFD, 0x2F, 0xB5, 0x23),  # v0.3
-            (0xFD, 0x2F, 0xB5, 0x24),  # v0.4
+            (0x28, 0xB5, 0x2F, 0xFD),
+            (0x22, 0xB5, 0x2F, 0xFD),  # v0.2
+            (0x23, 0xB5, 0x2F, 0xFD),  # v0.3
+            (0x24, 0xB5, 0x2F, 0xFD),  # v0.4
+            (0x1E, 0xB5, 0x2F, 0xFD),  # v0.1
         )
 
     @property
@@ -1521,7 +1501,7 @@ class Zstd(SingleExeCompressionFormat):
             cmd.append(str(src))
         return cmd
 
-    def get_list_command(self, path: PurePath) -> List[str]:
+    def get_list_command(self, path: PurePath) -> Optional[List[str]]:
         return [str(self.executable_path), "-l", str(path)]
 
     def parse_file_listing(self, listing: str) -> Tuple[int, int, float]:
@@ -1555,8 +1535,7 @@ class Zstd(SingleExeCompressionFormat):
 
 @compression_format
 class BZip2(SingleExeCompressionFormat):
-    """Implementation of CompressionFormat for bzip2 files.
-    """
+    """Implementation of CompressionFormat for bzip2 files."""
 
     @property
     def name(self) -> str:
@@ -1579,7 +1558,7 @@ class BZip2(SingleExeCompressionFormat):
         return 9
 
     @property
-    def magic_bytes(self) -> Tuple[Tuple[int, ...], ...]:
+    def magic_bytes(self) -> Optional[Tuple[Tuple[int, ...], ...]]:
         return ((0x42, 0x5A, 0x68),)
 
     @property
@@ -1630,8 +1609,7 @@ class BZip2(SingleExeCompressionFormat):
 
 @compression_format
 class Lzma(SingleExeCompressionFormat):
-    """Implementation of CompressionFormat for lzma (.xz) files.
-    """
+    """Implementation of CompressionFormat for lzma (.xz) files."""
 
     @property
     def name(self) -> str:
@@ -1654,7 +1632,7 @@ class Lzma(SingleExeCompressionFormat):
         return 2
 
     @property
-    def magic_bytes(self) -> Tuple[Tuple[int, ...], ...]:
+    def magic_bytes(self) -> Optional[Tuple[Tuple[int, ...], ...]]:
         return (
             (0x4C, 0x5A, 0x49, 0x50),  # lz
             (0xFD, 0x37, 0x7A, 0x58, 0x5A, 0x00),  # xz
@@ -1694,7 +1672,7 @@ class Lzma(SingleExeCompressionFormat):
             cmd.append(str(src))
         return cmd
 
-    def get_list_command(self, path: PurePath) -> List[str]:
+    def get_list_command(self, path: PurePath) -> Optional[List[str]]:
         return [str(self.executable_path), "-lv", str(path)]
 
     def parse_file_listing(self, listing: str) -> Tuple[int, int, float]:
@@ -1735,3 +1713,64 @@ class Lzma(SingleExeCompressionFormat):
 #         if src != STDIN:
 #             cmd.append(src)
 #         return cmd
+
+
+@compression_format
+class Brotli(SingleExeCompressionFormat):
+    @property
+    def name(self) -> str:
+        return "brotli"
+
+    @property
+    def exts(self) -> Tuple[str, ...]:
+        return ("br",)
+
+    @property
+    def system_commands(self) -> Tuple[str, ...]:
+        return ("brotli",)
+
+    @property
+    def compresslevel_range(self) -> Tuple[int, int]:
+        return 0, 11
+
+    @property
+    def default_compresslevel(self) -> int:
+        # although 11 is the default when using the command line
+        # tool, 4 gives the best tradeoff in speed and compression
+        # ratio (both faster and better ratio than gzip)
+        return 4
+
+    @property
+    def magic_bytes(self) -> Optional[Tuple[Tuple[int, ...], ...]]:
+        return None
+
+    @property
+    def mime_types(self) -> Tuple[str, ...]:
+        # none of these are official, but they are used in the wild
+        return ("application/brotli", "application/x-brotli", "application/x-br")
+
+    def get_command(
+        self,
+        operation: str,
+        src: PurePath = STDIN,
+        stdout: bool = True,
+        compresslevel: Optional[int] = 6,
+    ) -> List[str]:
+        cmd = [str(self.executable_path)]
+        if operation == "c":
+            compresslevel = self._get_compresslevel(compresslevel)
+            cmd.append("-{}".format(compresslevel))
+        elif operation == "d":
+            cmd.append("-d")
+        if stdout:
+            cmd.append("-c")
+        if src != STDIN:
+            cmd.append(str(src))
+        return cmd
+
+    def open_file_python(
+        self, path_or_file: PathOrFile, mode: ModeArg, **kwargs
+    ) -> FileLike:
+        raise UnsupportedOperation(
+            "the brotli python library does not have an open() function"
+        )
